<?php

namespace Country\Country\Http\Controllers;

use App\Http\Controllers\AdminController as BaseController;
use Form;
use Country\Country\Http\Requests\ZoneRequest;
use Country\Country\Interfaces\ZoneRepositoryInterface;
use Country\Country\Models\Zone;

/**
 * Admin web controller class.
 */
class ZoneAdminController extends BaseController
{
    // use ZoneWorkflow;
    /**
     * Initialize zone controller.
     *
     * @param type ZoneRepositoryInterface $zone
     *
     * @return type
     */
    public function __construct(ZoneRepositoryInterface $zone)
    {
        $this->repository = $zone;
        parent::__construct();
    }

    /**
     * Display a list of zone.
     *
     * @return Response
     */
    public function index(ZoneRequest $request)
    {
        if ($request->wantsJson()) {
            return $this->getJson($request);
        }
        $this   ->theme->prependTitle(trans('country::zone.names'));
        return $this->theme->of('country::admin.zone.index')->render();
    }

    /**
     * Display a list of zone.
     *
     * @return Response
     */
    public function getJson(ZoneRequest $request)
    {
        $pageLimit = $request->input('pageLimit');

        $zones  = $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->setPresenter('\\Country\\Country\\Repositories\\Presenter\\ZoneListPresenter')
                ->scopeQuery(function($query){
                    return $query->orderBy('id','DESC');
                })->paginate($pageLimit);
        $zones['recordsTotal']    = $zones['meta']['pagination']['total'];
        $zones['recordsFiltered'] = $zones['meta']['pagination']['total'];
        $zones['request']         = $request->all();
        return response()->json($zones, 200);

    }

    /**
     * Display zone.
     *
     * @param Request $request
     * @param Model   $zone
     *
     * @return Response
     */
    public function show(ZoneRequest $request, Zone $zone)
    {
        if (!$zone->exists) {
            return response()->view('country::admin.zone.new', compact('zone'));
        }

        Form::populate($zone);
        return response()->view('country::admin.zone.show', compact('zone'));
    }

    /**
     * Show the form for creating a new zone.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ZoneRequest $request)
    {

        $zone = $this->repository->newInstance([]);

        Form::populate($zone);

        return response()->view('country::admin.zone.create', compact('zone'));

    }

    /**
     * Create new zone.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ZoneRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $zone          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('country::zone.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/country/zone/'.$zone->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show zone for editing.
     *
     * @param Request $request
     * @param Model   $zone
     *
     * @return Response
     */
    public function edit(ZoneRequest $request, Zone $zone)
    {
        Form::populate($zone);
        return  response()->view('country::admin.zone.edit', compact('zone'));
    }

    /**
     * Update the zone.
     *
     * @param Request $request
     * @param Model   $zone
     *
     * @return Response
     */
    public function update(ZoneRequest $request, Zone $zone)
    {
        try {

            $attributes = $request->all();

            $zone->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('country::zone.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/country/zone/'.$zone->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/country/zone/'.$zone->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the zone.
     *
     * @param Model   $zone
     *
     * @return Response
     */
    public function destroy(ZoneRequest $request, Zone $zone)
    {

        try {

            $t = $zone->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('country::zone.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/country/zone/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/country/zone/'.$zone->getRouteKey()),
            ], 400);
        }
    }

}
